/*
 * Programming in Java, Jacobs University, 2015
 *
 * This class demonstrates how to use the Runnable interface and the
 * Thread class to create multiple threads forming a ThreadGroup. The
 * main thread signals the other threads to terminate by sending them
 * an advisory interrupt request.
 *
 * $ java A a b c d e f g h i j
 */

import java.lang.Runnable;
import java.lang.Thread;
import java.lang.ThreadGroup;
import java.util.concurrent.TimeUnit;

public class A implements Runnable
{
    private String s;
    private int ms;

    public A(String s)
    {
	this(s, 1000);
    }

    public A(String s, int ms)
    {
	this.s = s;
	this.ms = ms;
    }

    public void run() 
    {
	while (! Thread.currentThread().isInterrupted()) {
	    System.out.print(s);
	    try {
		TimeUnit.MILLISECONDS.sleep(ms);
	    } catch(InterruptedException e) {
		// reassert the interrupt to maintain the interrupt state 
		Thread.currentThread().interrupt();
	    }
	}
    }

    public static void main(String[] args)
	throws InterruptedException
    {
	Runnable[] runnables = { new A("."), new A("+", 300) };
	ThreadGroup g = new ThreadGroup("dots");

	for (Runnable r: runnables) {
	    new Thread(g, r).start();
	}

	TimeUnit.MILLISECONDS.sleep(4321);
	g.interrupt();			// ask other threads in g to terminate
	System.out.println();
    }
}
